#
# spec file for package liblrdf
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           liblrdf
Version:        0.6.1
Release:        1.16
Summary:        A library to Manipulate RDF Files for LADSPA Plug-Ins
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/swh/LRDF
Source:         https://github.com/swh/LRDF/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  ladspa-devel
BuildRequires:  libraptor-devel >= 0.9.11
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

%description
This is a library to make it easy to manipulate RDF files describing
LADSPA plug-ins. It can also be used for general RDF manipulation.

It can read RDF, XLM, and N3 files and export N3 files. Ot also has a
light taxonomic inference capability.

%package -n liblrdf2
Summary:        A library to Manipulate RDF Files for LADSPA Plug-Ins
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n liblrdf2
This is a library to make it easy to manipulate RDF files describing
LADSPA plug-ins. It can also be used for general RDF manipulation.

It can read RDF, XLM, and N3 files and export N3 files. Ot also has a
light taxonomic inference capability.

%package devel
Summary:        Development package for the liblrdf library
Group:          Development/Libraries/C and C++
Requires:       liblrdf2 = %{version}
Requires:       libraptor-devel

%description devel
This package contains the files needed to compile programs that use the
liblrdf library.

%prep
%setup -q -n LRDF-%{version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure --disable-static
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
make -C examples distclean
rm -f examples/.gitignore
rm -rf examples/.deps
rm -f examples/Makefile.*

%post -n liblrdf2 -p /sbin/ldconfig

%postun -n liblrdf2 -p /sbin/ldconfig

%files -n liblrdf2
%defattr(-,root,root)
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/lib*.so.2*

%files devel
%defattr(-,root,root)
%doc examples
%{_libdir}/lib*.so
%{_includedir}/*
%{_datadir}/ladspa
%{_libdir}/pkgconfig/*.pc
%exclude %{_libdir}/lib*.la

%changelog
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.1:
  - resolve license and build issues
* Tue Apr 10 2018 jengelh@inai.de
- Remove --with-pic which only makes sense for static libs.
- Fix SRPM group.
* Wed Mar 28 2018 dimstar@opensuse.org
- Also delete examples/.deps: with automake 1.16, this directory is
  newly also generated and remains back with make distcheck.
* Tue Feb 10 2015 p.drouand@gmail.com
- Update to version 0.5.0
  * Use raptor2 and openssl for MD5
- Remove patches; fixed on upstream release
  * liblrdf-symbol-conflict.diff
  * raptor2-compat.diff
- Update homepage Url
- Use download Url as source
- Add openssl-devel require; new upstream dependency
* Mon Jan 26 2015 idonmez@suse.com
- Add baselibs.conf as source file
- Run spec-cleaner
* Wed Jan 21 2015 olaf@aepfle.de
- BuildRequire libraptor-devel >= 0.9.11
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Sep 16 2011 tittiatcoke@gmail.com
- Added Raptor2 compatibility patch (upstream)
* Sun May  1 2011 toddrme2178@gmail.com
- Added 32bit compatibility libraries
- Removed self-obsoletes (fix for RPMLINT warning)
* Wed Apr 15 2009 tiwai@suse.de
- fix conflict of symbols (bnc#492257)
* Wed Dec 19 2007 crrodriguez@suse.de
- use library packaging policy
* Wed Dec 19 2007 crrodriguez@suse.de
- remove static libraries and "la" files
- fix -devel pakcage dependencies (missing libraptor-devel)
* Thu May  3 2007 wstephenson@suse.de
- libraptor1-devel -> libraptor-devel
* Thu May  3 2007 lrupp@suse.de
- require libraptor1-devel
* Tue Apr 17 2007 tiwai@suse.de
- fix buildrequires ladspa -> ladspa-devel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 24 2005 tiwai@suse.de
- updated to version 0.4.0.
* Thu Aug  5 2004 tiwai@suse.de
- updated to version 0.3.7.
* Fri Feb 27 2004 tiwai@suse.de
- removed the binareis from examples directory for installation.
* Thu Feb 26 2004 tiwai@suse.de
- updated to version 0.3.5.
* Tue Jan 13 2004 tiwai@suse.de
- build as non-root.
* Fri Jan  9 2004 tiwai@suse.de
- updated to version 0.3.2.
* Fri Jun  6 2003 tiwai@suse.de
- updated to version 0.3.1.
* Wed Apr  2 2003 tiwai@suse.de
- initial version: 0.2.4.
